@@ -4,6 +4,7 @@ from collections import defaultdict
 from typing import List, TYPE_CHECKING, Dict
 from .driver import Message, MessageSegment, Bot, MessageEvent, get_driver
 
+
 if TYPE_CHECKING:
     from .ayaka import AyakaApp
     from .group import AyakaGroup
@@ -16,6 +17,8 @@ _arg: ContextVar[Message] = ContextVar("_arg")
 _args: ContextVar[List[MessageSegment]] = ContextVar("_args")
 _message: ContextVar[Message] = ContextVar("_message")
 _cmd: ContextVar[str] = ContextVar("_cmd")
+_enter_exit_during: ContextVar[int] = ContextVar(
+    "_enter_exit_during", default=0)
 
 app_list: List["AyakaApp"] = []
 group_list: List["AyakaGroup"] = []
